Scriptname RealisticWaterTwoMCM extends ski_configbase

; ============================================================
; Version History and Check
; ============================================================
int function GetVersion()
	return 2
endFunction

; ============================================================
; xMarkers for enabling/disabling objects
; ============================================================
; Blacksmith Forge Water -------------------------------------------------------
ObjectReference Property RWT_BFW_ArthGraniteHill Auto
ObjectReference Property RWT_BFW_ArthKynesgrove Auto
ObjectReference Property RWT_BFW_ArthRorikstead Auto
ObjectReference Property RWT_ETaCMarker Auto

; Support Open Cities by linking duplicate objects to the marker. Vanilla objects have enabled state opposite of parent flag.
ObjectReference Property RWT_OpenCitiesMarker Auto

; Other Features -------------------------------------------------------
ObjectReference Property RWT_Waves_Skyrim Auto
;ObjectReference Property RWT_IcebergsToggle Auto

; ============================================================
; Bools for tracking toggle states
; name = initialState
; ============================================================
bool ArthGraniteHill = false
bool ArthKynesgrove = false
bool ArthRorikstead = false
bool OpenCities = false
bool ETaC = false
bool SkyrimWaves = true
;bool SkyrimIcebergs = true

; ============================================================
; Page Layouts
; @implements SKI_ConfigBase
; ============================================================
event OnConfigInit()
	Pages = new string[2]
	Pages[0] = "Blacksmith Forge Water"
	Pages[1] = "Optional Features"
endEvent

event OnVersionUpdate(int a_version)
	; a_version is the new version, CurrentVersion is the old version
	if (a_version >= 2 && CurrentVersion < 2)
		Debug.Trace(self + ": Updating script to version 2")
		Pages = new string[1]
		Pages[0] = "Mod Options"
	endIf
endEvent

event OnPageReset(string a_page)

	; Load custom .swf for animated logo
	if (a_page == "")
		LoadCustomContent("")
		return
	else
		UnloadCustomContent()
	endIf

; Blacksmith Forge Water Page -------------------------------------------------------
	if (a_page == "Mod Options")
		SetCursorFillMode(TOP_TO_BOTTOM)

		AddHeaderOption("Blacksmith Forge Water")
		AddToggleOptionST("ArthGraniteHillState", "The Fall of Granite Hill", ArthGraniteHill)
		AddToggleOptionST("ArthKynesgroveState", "Kynesgrove", ArthKynesgrove)
		AddToggleOptionST("ArthRoriksteadState", "Rorikstead", ArthRorikstead)
		AddToggleOptionST("OpenCitiesState", "Open Cities", OpenCities)
		AddToggleOptionST("ETaCState", "Expanded Towns and Cities SSE", ETaC)

		AddEmptyOption()
		
		SetCursorPosition(1)
		
		AddHeaderOption("Realistic Water Two Features")
		AddToggleOptionST("SkyrimWavesState", "Skyrim Waves", SkyrimWaves)
;		AddToggleOptionST("SkyrimIcebergsState", "Animated Icebergs", SkyrimIcebergs)

		AddEmptyOption()

	endIf
endEvent

; ============================================================
; Arthmoor Fall of Granite Hill Option
; ============================================================
state ArthGraniteHillState ; TOGGLE

	event OnSelectST()
		ArthGraniteHill = !ArthGraniteHill
		if ArthGraniteHill == true
			RWT_BFW_ArthGraniteHill.Enable()
		else
			RWT_BFW_ArthGraniteHill.Disable()
		endIf
		SetToggleOptionValueST(ArthGraniteHill)
	endEvent

	event OnDefaultST()
		ArthGraniteHill = false
		if ArthGraniteHill == true
			RWT_BFW_ArthGraniteHill.Enable()
		else
			RWT_BFW_ArthGraniteHill.Disable()
		endIf
		SetToggleOptionValueST(ArthGraniteHill)
	endEvent

	event OnHighlightST()
		SetInfoText("Toggles the Blacksmith Forge Water for Arthmoors The Fall of Granite Hill. Users should uncheck this once the town is destroyed.")
	endEvent
	
endState

; ============================================================
; Arthmoor Kynesgrove
; ============================================================
state ArthKynesgroveState ; TOGGLE

	event OnSelectST()
		ArthKynesgrove = !ArthKynesgrove
		if ArthKynesgrove == true
			RWT_BFW_ArthKynesgrove.Enable()
		else
			RWT_BFW_ArthKynesgrove.Disable()
		endIf
		SetToggleOptionValueST(ArthKynesgrove)
	endEvent

	event OnDefaultST()
		ArthKynesgrove = false
		if ArthKynesgrove == true
			RWT_BFW_ArthKynesgrove.Enable()
		else
			RWT_BFW_ArthKynesgrove.Disable()
		endIf
		SetToggleOptionValueST(ArthKynesgrove)
	endEvent

	event OnHighlightST()
		SetInfoText("Toggles the Blacksmith Forge Water for Arthmoors Kynesgrove.")
	endEvent
	
endState

; ============================================================
; Arthmoor Rorikstead Option
; ============================================================
state ArthRoriksteadState ; TOGGLE

	event OnSelectST()
		ArthRorikstead = !ArthRorikstead
		if ArthRorikstead == true
			RWT_BFW_ArthRorikstead.Enable()
		else
			RWT_BFW_ArthRorikstead.Disable()
		endIf
		SetToggleOptionValueST(ArthRorikstead)
	endEvent

	event OnDefaultST()
		ArthRorikstead = false
		if ArthRorikstead == true
			RWT_BFW_ArthRorikstead.Enable()
		else
			RWT_BFW_ArthRorikstead.Disable()
		endIf
		SetToggleOptionValueST(ArthRorikstead)
	endEvent

	event OnHighlightST()
		SetInfoText("Toggles the Blacksmith Forge Water for Arthmoors Rorikstead.")
	endEvent
	
endState

; ============================================================
; Open Cities Option
; ============================================================
state OpenCitiesState ; TOGGLE

	event OnSelectST()
		OpenCities = !OpenCities
		if OpenCities == true
			RWT_OpenCitiesMarker.Enable()
		else
			RWT_OpenCitiesMarker.Disable()
		endIf
		SetToggleOptionValueST(OpenCities)
	endEvent

	event OnDefaultST()
		OpenCities = false
		if OpenCities == true
			RWT_OpenCitiesMarker.Enable()
		else
			RWT_OpenCitiesMarker.Disable()
		endIf
		SetToggleOptionValueST(OpenCities)
	endEvent

	event OnHighlightST()
		SetInfoText("Toggles the Blacksmith Forge Water for Open Cities.")
	endEvent
	
endState

; ============================================================
; ETaC Option
; ============================================================
state ETaCState ; TOGGLE

	event OnSelectST()
		ETaC = !ETaC
		if ETaC == true
			RWT_ETaCMarker.Enable()
		else
			RWT_ETaCMarker.Disable()
		endIf
		SetToggleOptionValueST(ETaC)
	endEvent

	event OnDefaultST()
		ETaC = false
		if ETaC == true
			RWT_ETaCMarker.Enable()
		else
			RWT_ETaCMarker.Disable()
		endIf
		SetToggleOptionValueST(ETaC)
	endEvent

	event OnHighlightST()
		SetInfoText("Toggles the Blacksmith Forge Water for the expanded towns in ETaC.")
	endEvent
	
endState

; ============================================================
; Waves for Skyrim Option
; ============================================================
state SkyrimWavesState ; TOGGLE

	event OnSelectST()
		SkyrimWaves = !SkyrimWaves
		if SkyrimWaves == true
			RWT_Waves_Skyrim.Enable()
		else
			RWT_Waves_Skyrim.Disable()
		endIf
		SetToggleOptionValueST(SkyrimWaves)
	endEvent

	event OnDefaultST()
		SkyrimWaves = true
		if SkyrimWaves == true
			RWT_Waves_Skyrim.Enable()
		else
			RWT_Waves_Skyrim.Disable()
		endIf
		SetToggleOptionValueST(SkyrimWaves)
	endEvent

	event OnHighlightST()
		SetInfoText("Enables the waves along the coasts of Skyrim. Also adds additional waves to Japhet's Folly and Solstheim.")
	endEvent
	
endState

; ============================================================
; Icebergs Option
; ============================================================
;state SkyrimIcebergsState ; TOGGLE
;
;	event OnSelectST()
;		SkyrimIcebergs = !SkyrimIcebergs
;		if SkyrimIcebergs == true
;			RWT_IcebergsToggle.Enable()
;		else
;			RWT_IcebergsToggle.Disable()
;		endIf
;		SetToggleOptionValueST(SkyrimIcebergs)
;	endEvent
;
;	event OnDefaultST()
;		SkyrimIcebergs = true
;		if SkyrimIcebergs == true
;			RWT_IcebergsToggle.Enable()
;		else
;			RWT_IcebergsToggle.Disable()
;		endIf
;		SetToggleOptionValueST(SkyrimIcebergs)
;	endEvent
;
;	event OnHighlightST()
;		SetInfoText("Toggles the animated icebergs along the coasts of Skyrim.")
;	endEvent
;	
;endState